@@ -15,7 +15,6 @@ from ipaddress import (
     IPv6Network,
 )
 from pathlib import Path
-from random import choice, uniform
 from typing import (
     Any,
     Callable,
@@ -110,6 +109,7 @@ from pydantic_factories.utils import (
     is_literal,
     is_optional,
     is_pydantic_model,
+    random,
 )
 from pydantic_factories.value_generators.complex_types import handle_complex_type
 from pydantic_factories.value_generators.primitives import (
@@ -129,6 +129,14 @@ class ModelFactory(ABC, Generic[T]):
     __async_persistence__: Optional[Union[Type[AsyncPersistenceProtocol[T]], AsyncPersistenceProtocol[T]]] = None
     __allow_none_optionals__: bool = True
 
+    @classmethod
+    def seed_random(cls, seed: int):
+        """
+        Seeds Fake and random methods with seed
+        """
+        random.seed(seed)
+        Faker.seed(seed)
+
     @classmethod
     def is_model_factory(cls, value: Any) -> bool:
         """Method to determine if a given value is a subclass of ModelFactory"""
@@ -252,10 +260,10 @@ class ModelFactory(ABC, Generic[T]):
             ByteSize: faker.pyint,
             PositiveInt: faker.pyint,
             FilePath: create_path,
-            NegativeFloat: lambda: uniform(-100, -1),
+            NegativeFloat: lambda: random.uniform(-100, -1),
             NegativeInt: lambda: faker.pyint() * -1,
             PositiveFloat: faker.pyint,
-            NonPositiveFloat: lambda: uniform(-100, 0),
+            NonPositiveFloat: lambda: random.uniform(-100, 0),
             NonNegativeInt: faker.pyint,
             StrictInt: faker.pyint,
             StrictBool: faker.pybool,
@@ -326,7 +334,7 @@ class ModelFactory(ABC, Generic[T]):
     @classmethod
     def handle_enum(cls, outer_type: EnumMeta) -> Any:
         """Method that converts an enum to a list and picks a random element out of it"""
-        return choice(list(outer_type))
+        return random.choice(list(outer_type))
 
     @classmethod
     def handle_factory_field(cls, field_name: str) -> Any:
